systemd/SOURCES/0332-cgroup-make-sure-that-...

41 lines
1.6 KiB
Diff

From 5fc2d94fbf8271bb340e834f832af5d890c267bf Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Michal=20Sekleta=CC=81r?= <msekleta@redhat.com>
Date: Tue, 3 Mar 2020 11:45:00 +0100
Subject: [PATCH] cgroup: make sure that cpuset is supported on cgroup v2 and
disabled with v1
Resolves: #1808940
(rhel-only)
---
src/basic/cgroup-util.c | 7 +++++--
1 file changed, 5 insertions(+), 2 deletions(-)
diff --git a/src/basic/cgroup-util.c b/src/basic/cgroup-util.c
index 6f47c3aacb..92bc1f2543 100644
--- a/src/basic/cgroup-util.c
+++ b/src/basic/cgroup-util.c
@@ -2353,10 +2353,10 @@ int cg_mask_supported(CGroupMask *ret) {
if (r < 0)
return r;
/* Currently, we support the cpu, memory, io and pids
* controller in the unified hierarchy, mask
* everything else off. */
- mask &= CGROUP_MASK_CPU | CGROUP_MASK_MEMORY | CGROUP_MASK_IO | CGROUP_MASK_PIDS;
+ mask &= CGROUP_MASK_CPU | CGROUP_MASK_MEMORY | CGROUP_MASK_IO | CGROUP_MASK_PIDS | CGROUP_MASK_CPUSET;
} else {
CGroupController c;
@@ -2367,6 +2367,9 @@ int cg_mask_supported(CGroupMask *ret) {
for (c = 0; c < _CGROUP_CONTROLLER_MAX; c++) {
const char *n;
+ if (c == CGROUP_CONTROLLER_CPUSET)
+ continue;
+
n = cgroup_controller_to_string(c);
if (controller_is_accessible(n) >= 0)
mask |= CGROUP_CONTROLLER_TO_MASK(c);
@@ -2353,10 +2353,10 @@ int cg_mask_supported(CGroupMask *ret) {
if (r < 0)
return r;
- /* Currently, we support the cpu, memory, io and pids
+ /* Currently, we support the cpu, memory, io, pids and cpuset
* controller in the unified hierarchy, mask
* everything else off. */